@@ -164,11 +164,11 @@ class CausalTreeLearn(CausalTree):
         val_lm0 = np.sum(val_yy * val_denom_control_lower, axis=1) / np.sum(val_denom_control_lower, axis=1)
         val_lower_effect = val_lm1 - val_lm0
 
-        train_upper_mse = train_upper_effect ** 2
-        upper_cost = np.abs(train_upper_effect - val_upper_effect)
+        train_upper_mse = (1 - self.weight) * train_upper_effect ** 2
+        upper_cost = self.weight * np.abs(train_upper_effect - val_upper_effect)
         upper_obj = train_upper_mse - upper_cost
-        train_lower_mse = train_lower_effect ** 2
-        lower_cost = np.abs(train_lower_effect - val_lower_effect)
+        train_lower_mse = (1 - self.weight) * train_lower_effect ** 2
+        lower_cost = self.weight * np.abs(train_lower_effect - val_lower_effect)
         lower_obj = train_lower_mse - lower_cost
 
         split_obj = upper_obj + lower_obj
@@ -423,4 +423,4 @@ class CausalTreeLearn(CausalTree):
         best_split_obj = split_obj[best_obj_idx]
         val = unique_vals[best_obj_idx]
 
-        return best_split_obj, best_upper_obj, best_lower_obj, val
\ No newline at end of file
+        return best_split_obj, best_upper_obj, best_lower_obj, val
